# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-07-22 00:39
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('openunipay', '0005_product'),
    ]

    operations = [
        migrations.AddField(
            model_name='weixinorder',
            name='openid',
            field=models.CharField(blank=True, editable=False, max_length=128, null=True, verbose_name='用户标识(openId)'),
        ),
        migrations.AlterField(
            model_name='product',
            name='productid',
            field=models.CharField(max_length=50, primary_key=True, serialize=False, verbose_name='商品ID'),
        ),
    ]
