# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-07-21 12:30
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('openunipay', '0004_weixinqrpayentity_weixinqrpayrecord'),
    ]

    operations = [
        migrations.CreateModel(
            name='Product',
            fields=[
                ('productid', models.CharField(editable=False, max_length=50, primary_key=True, serialize=False, verbose_name='商品ID')),
                ('product_desc', models.CharField(max_length=128, verbose_name='商品描述')),
                ('product_detail', models.TextField(max_length=1000, verbose_name='商品详情')),
                ('fee', models.DecimalField(decimal_places=0, max_digits=6, verbose_name='金额(单位:分)')),
                ('weinxin_qrurl', models.CharField(blank=True, max_length=500, null=True, verbose_name='微信扫码支付URL')),
                ('date_create', models.DateTimeField(auto_now_add=True, verbose_name='创建时间')),
                ('date_update', models.DateTimeField(auto_now=True, verbose_name='修改时间')),
            ],
            options={
                'verbose_name_plural': '商品',
                'verbose_name': '商品',
            },
        ),
    ]
