# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-07-21 00:41
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('openunipay', '0003_auto_20170117_1106'),
    ]

    operations = [
        migrations.CreateModel(
            name='WeiXinQRPayEntity',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('appid', models.CharField(editable=False, max_length=32, verbose_name='公众账号ID')),
                ('mch_id', models.CharField(editable=False, max_length=32, verbose_name='商户号')),
                ('time_stamp', models.CharField(editable=False, max_length=10, verbose_name='时间戳')),
                ('product_id', models.CharField(editable=False, max_length=32, verbose_name='商品ID')),
            ],
            options={
                'verbose_name_plural': '微信扫码支付-二维码URL',
                'verbose_name': '微信扫码支付-二维码URL',
            },
        ),
        migrations.CreateModel(
            name='WeiXinQRPayRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('appid', models.CharField(editable=False, max_length=32, verbose_name='公众账号ID')),
                ('mch_id', models.CharField(editable=False, max_length=32, verbose_name='商户号')),
                ('openid', models.CharField(editable=False, max_length=128, verbose_name='用户标识')),
                ('product_id', models.CharField(editable=False, max_length=32, verbose_name='商品ID')),
            ],
            options={
                'verbose_name_plural': '微信扫码支付-扫码纪录',
                'verbose_name': '微信扫码支付-扫码纪录',
            },
        ),
    ]
